==> huaweicloudsdkimage-3.0.84-py2.py3-none-any.whl: huaweicloudsdkimage/v2/model/run_celebrity_recognition_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunCelebrityRecognitionResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'result': 'list[CelebrityRecognitionResultBody]'
    }

    attribute_map = {
        'result': 'result'
    }

    def __init__(self, result=None):
        """RunCelebrityRecognitionResponse - a model defined in huaweicloud sdk"""
        
        super(RunCelebrityRecognitionResponse, self).__init__()

        self._result = None
        self.discriminator = None

        if result is not None:
            self.result = result

    @property
    def result(self):
        """Gets the result of this RunCelebrityRecognitionResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :return: The result of this RunCelebrityRecognitionResponse.
        :rtype: list[CelebrityRecognitionResultBody]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this RunCelebrityRecognitionResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :param result: The result of this RunCelebrityRecognitionResponse.
        :type: list[CelebrityRecognitionResultBody]
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunCelebrityRecognitionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkimage-3.0.99-py2.py3-none-any.whl: huaweicloudsdkimage/v2/model/run_celebrity_recognition_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunCelebrityRecognitionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'result': 'list[CelebrityRecognitionResultBody]'
    }

    attribute_map = {
        'result': 'result'
    }

    def __init__(self, result=None):
        """RunCelebrityRecognitionResponse

        The model defined in huaweicloud sdk

        :param result: 调用成功时表示调用结果。  调用失败时无此字段。 
        :type result: list[:class:`huaweicloudsdkimage.v2.CelebrityRecognitionResultBody`]
        """
        
        super(RunCelebrityRecognitionResponse, self).__init__()

        self._result = None
        self.discriminator = None

        if result is not None:
            self.result = result

    @property
    def result(self):
        """Gets the result of this RunCelebrityRecognitionResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :return: The result of this RunCelebrityRecognitionResponse.
        :rtype: list[:class:`huaweicloudsdkimage.v2.CelebrityRecognitionResultBody`]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this RunCelebrityRecognitionResponse.

        调用成功时表示调用结果。  调用失败时无此字段。 

        :param result: The result of this RunCelebrityRecognitionResponse.
        :type result: list[:class:`huaweicloudsdkimage.v2.CelebrityRecognitionResultBody`]
        """
        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunCelebrityRecognitionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
